@@ -78,9 +78,9 @@
 #define TOKEN1(tok)  TRACE (("TOKEN  %s (%s)\n", tok, Tcl_GetString(context->obj)))
 #define REDUCE(rule) TRACE (("REDUCE %s\n", rule))
 
-#define TRUE_O  (Tcl_NewStringObj("true", 4))
-#define FALSE_O (Tcl_NewStringObj("false", 5))
-#define NULL_O  (Tcl_NewStringObj("null", 4))
+#define TRUE_O  (Tcl_NewStringObj("true",  4)) /* OK tcl9 */
+#define FALSE_O (Tcl_NewStringObj("false", 5)) /* OK tcl9 */
+#define NULL_O  (Tcl_NewStringObj("null",  4)) /* OK tcl9 */
 
 typedef union YYSTYPE YYSTYPE;
 
@@ -1289,7 +1289,7 @@ yyreduce:
   case 8:
 #line 100 "json.y" /* yacc.c:1646  */
     {	
-		(yyval.obj) = Tcl_NewListObj(1, &(yyvsp[0].obj));
+		(yyval.obj) = Tcl_NewListObj(1, &(yyvsp[0].obj)); /* OK tcl9 */
 	}
 #line 1295 "json.tab.c" /* yacc.c:1646  */
     break;
@@ -1306,7 +1306,7 @@ yyreduce:
   case 10:
 #line 111 "json.y" /* yacc.c:1646  */
     {
-	        (yyval.obj) = Tcl_NewListObj(0, NULL);
+	        (yyval.obj) = Tcl_NewListObj(0, NULL); /* OK tcl9 */
 		Tcl_ListObjAppendElement(NULL, (yyval.obj), (yyvsp[0].keyval).key);
 		Tcl_ListObjAppendElement(NULL, (yyval.obj), (yyvsp[0].keyval).val);
 	}
@@ -1596,11 +1596,11 @@ jsonparse (struct context* context)
 #define	STORESTRINGSEGMENT()				\
 	if (initialized) {				\
 		if (context->text != bp) {		\
-			Tcl_AppendToObj(context->obj,	\
+			Tcl_AppendToObj(context->obj, /* OK tcl9 */	\
 			    bp, context->text - bp);	\
 		}					\
 	} else {					\
-		context->obj = Tcl_NewStringObj(	\
+		context->obj = Tcl_NewStringObj( /* OK tcl9 */	\
 		    bp, context->text - bp);		\
 		initialized = 1;			\
 	}
@@ -1685,19 +1685,20 @@ jsonlexp(YYSTYPE *lvalp, struct context *context)
 	 * are:
 	 *       \"  \\  \/  \b  \f  \n  \r  \t  \uXXXX
 	 */
-	char	buf[TCL_UTF_MAX];
-	int	len, consumed;
+	char	 buf[TCL_UTF_MAX];
+	Tcl_Size len;
+	int      consumed;
 
 	STORESTRINGSEGMENT();
 
 	/*
 	 * Perform additional checks to restrict the set of accepted
 	 * escape sequence to what is allowed by json.org instead of
-	 * Tcl_UtfBackslash.
+	 * Tcl_UtfBackslash. -- OK tcl9
 	 */
 
 	if (!HAVE(1)) {
-	  Tcl_AppendToObj(context->obj, "\\", 1);
+	  Tcl_AppendToObj(context->obj, "\\", 1); /* OK tcl9 */
 	  yyerror(context,"incomplete escape at <<eof> error");
 	  TOKEN("incomplete escape at <<eof>> error");
 	  return -1;
@@ -1714,30 +1715,30 @@ jsonlexp(YYSTYPE *lvalp, struct context *context)
 	    break;
 	  case 'u':
 	    if (!HAVE(5)) {
-	      Tcl_AppendToObj(context->obj, "\\u", 2);
+	      Tcl_AppendToObj(context->obj, "\\u", 2); /* OK tcl9 */
 	      yyerror(context,"incomplete escape at <<eof> error");
 	      TOKEN("incomplete escape at <<eof>> error");
 	      return -1;
 	    }
 	    break;
 	  default:
-	    Tcl_AppendToObj(context->obj, context->text + 1, 1);
+	    Tcl_AppendToObj(context->obj, context->text + 1, 1); /* OK tcl9 */
 	    yyerror(context,"bad escape");
 	    TOKEN("bad escape");
 	    return -1;
 	}
 
 	/*
-	 * XXX Tcl_UtfBackslash() may be more
+	 * XXX Tcl_UtfBackslash() may be more -- OK tcl9
 	 * XXX permissive, than JSON standard.
 	 * XXX But that may be a good thing:
 	 * XXX "be generous in what you accept".
 	 */
-	len = Tcl_UtfBackslash(context->text,
+	len = Tcl_UtfBackslash(context->text, /* OK tcl9 */
 			       &consumed, buf);
 	DRAIN(consumed - 1);
 	bp = context->text + 1;
-	Tcl_AppendToObj(context->obj, buf, len);
+	Tcl_AppendToObj(context->obj, buf, len); /* OK tcl9 */
       }
       continue;
     }
@@ -1805,7 +1806,7 @@ jsonlexp(YYSTYPE *lvalp, struct context *context)
     if (end == context->text)
       goto bareword; /* Nothing parsed */
 
-    context->obj = Tcl_NewStringObj (context->text,
+    context->obj = Tcl_NewStringObj (context->text, /* OK tcl9 */
 				     end - context->text);
 
     context->remaining -= (end - context->text);
@@ -1883,12 +1884,12 @@ jsonlex(struct context *context)
 	int	len, consumed;
 
 	/*
-	 * XXX Tcl_UtfBackslash() may be more
+	 * XXX Tcl_UtfBackslash() may be more -- OK tcl9
 	 * XXX permissive, than JSON standard.
 	 * XXX But that may be a good thing:
 	 * XXX "be generous in what you accept".
 	 */
-	len = Tcl_UtfBackslash(context->text, &consumed, buf);
+	len = Tcl_UtfBackslash(context->text, &consumed, buf); /* OK tcl9 */
 	DRAIN(consumed - 1);
       }
       continue;
@@ -1966,22 +1967,28 @@ jsonlex(struct context *context)
 static void
 jsonerror(struct context *context, const char *message)
 {
-  char *fullmessage;
-  char *yytext;
-  int   yyleng;
+  char*    fullmessage;
+  char*    yytext;
+  Tcl_Size yyleng;
 
   if (context->has_error) return;
 
   if (context->obj) {
-    yytext = Tcl_GetStringFromObj(context->obj, &yyleng);
+    yytext = Tcl_GetStringFromObj(context->obj, &yyleng); /* OK tcl9 */
     fullmessage = Tcl_Alloc(strlen(message) + 63 + yyleng);
 
-    sprintf(fullmessage, "%s %d bytes before end, around ``%.*s''",
-	    message, context->remaining, yyleng, yytext);
+    sprintf(fullmessage,
+	    "%s %" TCL_SIZE_MODIFIER "d bytes before end, around ``%.*s''",
+	    message, context->remaining, (int) yyleng, yytext);
+    /* Beware: The `%.*s` format accepts only `int` length information.
+     * Which means a string longer than 2GB will not print correctly.
+     * I am accepting this under the assumption that such a large string
+     * will not happen.
+     */
   } else {
     fullmessage = Tcl_Alloc(strlen(message) + 63);
 
-    sprintf(fullmessage, "%s %d bytes before end",
+    sprintf(fullmessage, "%s %" TCL_SIZE_MODIFIER "d bytes before end",
 	    message, context->remaining);
   }
 
