@@ -5,9 +5,9 @@
 #ifndef _MS_H
 #define _MS_H 1
 
-#include "tcl.h"
+#include "tclpre9compat.h"
 
-int paramms_objcmd (ClientData cd, Tcl_Interp* interp, int objc, Tcl_Obj* CONST* objv);
+int paramms_objcmd (ClientData cd, Tcl_Interp* interp, Tcl_Size objc, Tcl_Obj* CONST* objv);
 
 #endif /* _MS_H */
 
